@@ -1365,42 +1365,38 @@ def test_ria_http_storedataladorg(path=None):
 @with_tempfile
 @with_tempfile
 @with_tempfile
+@with_tempfile
 def test_ephemeral(origin_path=None, bare_path=None,
-                   clone1_path=None, clone2_path=None, clone3_path=None):
+                   clone1_path=None, clone2_path=None,
+                   clone3_path=None, clone4_path=None):
+    can_symlink = has_symlink_capability()
 
     file_test = Path('ds') / 'test.txt'
     file_testsub = Path('ds') / 'subdir' / 'testsub.txt'
 
     origin = Dataset(origin_path).create(force=True)
     origin.save()
+
+    def check_clone(clone_):
+        # common checks to do on a clone
+        eq_(clone_.config.get("annex.private"), "true")
+        if can_symlink:
+            clone_annex = (clone_.repo.dot_git / 'annex')
+            ok_(clone_annex.is_symlink())
+            ok_(clone_annex.resolve().samefile(origin.repo.dot_git / 'annex'))
+            if not clone_.repo.is_managed_branch():
+                # TODO: We can't properly handle adjusted branch yet
+                eq_((clone_.pathobj / file_test).read_text(), 'some')
+                eq_((clone_.pathobj / file_testsub).read_text(), 'somemore')
+
     # 1. clone via path
     clone1 = clone(origin_path, clone1_path, reckless='ephemeral')
-    eq_(clone1.config.get("annex.private"), "true")
-
-    can_symlink = has_symlink_capability()
-
-    if can_symlink:
-        clone1_annex = (clone1.repo.dot_git / 'annex')
-        ok_(clone1_annex.is_symlink())
-        ok_(clone1_annex.resolve().samefile(origin.repo.dot_git / 'annex'))
-        if not clone1.repo.is_managed_branch():
-            # TODO: We can't properly handle adjusted branch yet
-            eq_((clone1.pathobj / file_test).read_text(), 'some')
-            eq_((clone1.pathobj / file_testsub).read_text(), 'somemore')
+    check_clone(clone1)
 
     # 2. clone via file-scheme URL
     clone2 = clone('file://' + Path(origin_path).as_posix(), clone2_path,
                    reckless='ephemeral')
-    eq_(clone2.config.get("annex.private"), "true")
-
-    if can_symlink:
-        clone2_annex = (clone2.repo.dot_git / 'annex')
-        ok_(clone2_annex.is_symlink())
-        ok_(clone2_annex.resolve().samefile(origin.repo.dot_git / 'annex'))
-        if not clone2.repo.is_managed_branch():
-            # TODO: We can't properly handle adjusted branch yet
-            eq_((clone2.pathobj / file_test).read_text(), 'some')
-            eq_((clone2.pathobj / file_testsub).read_text(), 'somemore')
+    check_clone(clone2)
 
     # 3. add something to clone1 and push back to origin availability from
     # clone1 should not be propagated (we declared 'here' dead to that end)
@@ -1456,6 +1452,12 @@ def test_ephemeral(origin_path=None, bare_path=None,
         ok_(eph_annex.is_symlink())
         ok_(eph_annex.resolve().samefile(Path(bare_path) / 'annex'))
 
+    # 5. ephemeral clone using relative path
+    # https://github.com/datalad/datalad/issues/7469
+    with chpwd(op.dirname(origin_path)):
+        clone4 = clone(op.basename(origin_path), op.basename(clone4_path), reckless='ephemeral')
+    check_clone(clone4)
+
 
 @with_tempfile(mkdir=True)
 def test_clone_unborn_head(path=None):
@@ -1727,6 +1729,10 @@ def test_url_mapping_specs():
             ({},
              'https://github.com/datalad/testrepo_gh/sub _1',
              'https://github.com/datalad/testrepo_gh-sub__1'),
+            # trailing slash is not mapped
+            ({},
+             'https://github.com/datalad/testrepo_gh/sub _1/',
+             'https://github.com/datalad/testrepo_gh-sub__1/'),
             # and on deep subdataset too
             ({},
              'https://github.com/datalad/testrepo_gh/sub _1/d/sub_-  1',
