@@ -750,7 +750,18 @@ def test_AnnexRepo_always_commit(path=None):
     # Now git-annex log should show the addition:
     out_list = list(repo.call_annex_items_(['log']))
     eq_(len(out_list), 1)
-    assert_in(file1, out_list[0])
+
+    quote = lambda s: s.replace('"', r'\"')
+    def assert_in_out(filename, out):
+        filename_quoted = quote(filename)
+        if repo._check_version_kludges('quotepath-respected') == "no":
+            assert_in(filename, out)
+        elif repo._check_version_kludges('quotepath-respected') == "maybe":
+            assert filename in out or filename_quoted in out
+        else:
+            assert_in(filename_quoted, out)
+    assert_in_out(file1, out_list[0])
+
     # check git log of git-annex branch:
     # expected: initial creation, update (by annex add) and another
     # update (by annex log)
@@ -765,16 +776,17 @@ def test_AnnexRepo_always_commit(path=None):
         out = repo.call_annex(['log'])
 
         # And we see only the file before always_commit was set to false:
-        assert_in(file1, out)
+        assert_in_out(file1, out)
         assert_not_in(file2, out)
+        assert_not_in(quote(file2), out)
 
     # With always_commit back to True, do something that will trigger a commit
     # on the annex branches.
     repo.call_annex(['sync'])
 
     out = repo.call_annex(['log'])
-    assert_in(file1, out)
-    assert_in(file2, out)
+    assert_in_out(file1, out)
+    assert_in_out(file2, out)
 
     # Now git knows as well:
     eq_(get_annex_commit_counts(), n_annex_commits_initial + 2)
@@ -2197,16 +2209,23 @@ def _test_add_under_subdir(path):
 def test_error_reporting(path=None):
     ar = AnnexRepo(path, create=True)
     res = ar.call_annex_records(['add'], files='gl\\orious BS')
-    eq_(
-        res,
-        [{
-            'command': 'add',
-            # whole thing, despite space, properly quotes backslash
-            'file': 'gl\\orious BS',
-            'note': 'not found',
-            'error-messages': ['File unknown to git'],
-            'success': False}]
-    )
+    target = {
+        'command': 'add',
+        # whole thing, despite space, properly quotes backslash
+        'file': 'gl\\orious BS',
+        'note': 'not found',
+        'success': False
+    }
+    assert len(res) >= 1
+    if 'message-id' in res[0]:
+        # new since ~ 10.20230407-99-gbe36e208c2
+        target['message-id'] = 'FileNotFound'
+        target['input'] = ['gl\\orious BS']
+        target['error-messages'] = ['git-annex: gl\\orious BS not found']
+    else:
+        # our own produced record
+        target['error-messages'] = ['File unknown to git']
+    eq_(res, [target])
 
 
 @with_tree(tree={
@@ -2380,6 +2399,31 @@ def test_commit_annex_commit_changed(path=None, *, unlock):
     ok_file_under_git(path, 'tobechanged-annex', annexed=True)
 
 
+_test_unannex_tree = {
+    OBSCURE_FILENAME: 'content1',
+    OBSCURE_FILENAME + ".dat": 'content2',
+}
+if not on_windows and (
+        external_versions['cmd:annex'] <= '10.20230407' or external_versions['cmd:annex'] >= '10.20230408'
+):
+    # Only whenever we are not within the development versions of the 10.20230407
+    # where we cannot do version comparison relibalye,
+    # the case where we have entire filename within ""
+    _test_unannex_tree[f'"{OBSCURE_FILENAME}"'] = 'content3'
+
+
+@with_tree(tree=_test_unannex_tree)
+def test_unannex_etc(path=None):
+    # Primarily to test if quote/unquote/not-quote'ing work for tricky
+    # filenames. Ref: https://github.com/datalad/datalad/pull/7372
+    repo = AnnexRepo(path)
+    files = list(_test_unannex_tree)
+    # here it is through json so kinda guaranteed to work but let's check too
+    assert files == [x['file'] for x in repo.add(files)]
+    assert sorted(files) == sorted(repo.get_annexed_files())
+    assert files == repo.unannex(files)
+
+
 @slow  # 15 + 17sec on travis
 @pytest.mark.parametrize("cls", [GitRepo, AnnexRepo])
 @with_tempfile(mkdir=True)
